@@ -6,30 +6,26 @@ Download
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
-download_init_required_fields = (
+crawl_download_extra_fields = (
+    'id',
     'account_id',
     'project_id',
     'crawl_id',
     'report_id',
-    'report_type'
 )
 
-download_init_optional_fields = (
-    'filter',
-    'output_type'
-)
-
-download_mutable_fields = ()
-
-download_immutable_fields = (
-    'id',
+crawl_download_mutable_fields = crawl_download_extra_fields + (
+    'report_type',
     'status',
     'date_requested',
     'total_rows',
     'report_file',
-
     'report_name',
+    'filter',
+    'output_type',
+)
 
+crawl_download_immutable_fields = (
     '_account_href',
     '_project_href',
     '_crawl_href',
@@ -37,21 +33,19 @@ download_immutable_fields = (
     '_report_href_alt',
     '_report_template_href',
     '_report_type_href',
-    '_href'
-
+    '_href',
 )
 
-download_fields = download_init_required_fields + download_init_optional_fields + download_mutable_fields + \
-                  download_immutable_fields
+crawl_download_fields = crawl_download_mutable_fields + crawl_download_immutable_fields
 
 
 class DeepCrawlCrawlDownloads(ImmutableAttributesMixin):
     """
     Crawls Download class
     """
-    __slots__ = download_fields
+    __slots__ = crawl_download_fields
 
-    mutable_attributes = download_init_required_fields + download_init_optional_fields + download_mutable_fields
+    mutable_attributes = crawl_download_mutable_fields
 
     def __init__(self, download_data, account_id, project_id, crawl_id):
         # relations
@@ -89,11 +83,57 @@ class DeepCrawlCrawlDownloads(ImmutableAttributesMixin):
     def __str__(self):
         return f"[{self.id}] {self.report_name.title()} {self.report_type} - {self.output_type} ({self.status})"
 
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in crawl_download_mutable_fields}
 
-class DeepCrawlReportDownload:
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in crawl_download_immutable_fields}
+
+
+report_download_extra_fields = (
+    "id",
+    "account_id",
+    "project_id",
+    "crawl_id",
+    "report_id",
+)
+
+report_download_mutable_fields = report_download_extra_fields + (
+    "report_type",
+    "status",
+    "filter",
+    "output_type",
+    "date_requested",
+    "total_rows",
+    "output_requested"
+)
+
+report_download_immutable_fields = (
+
+)
+
+report_download_fields = report_download_mutable_fields + report_download_immutable_fields
+
+
+class DeepCrawlReportDownload(ImmutableAttributesMixin):
     """
     Reports Download class
     """
+
+    __slots__ = report_download_fields
+
+    mutable_attributes = report_download_mutable_fields
+
     def __init__(self, account_id, project_id, crawl_id, report_id, download_data: dict):
         # relations
         self.id = download_data.get("id")
@@ -112,3 +152,21 @@ class DeepCrawlReportDownload:
 
         # only in create (I think.)
         self.output_requested = download_data.get('output_requested')
+
+        super(DeepCrawlReportDownload, self).__init__()
+
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in report_download_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in report_download_immutable_fields}
