@@ -38,3 +38,11 @@ class MajesticSettings(ImmutableAttributesMixin):
         self._href = majestic_settings.get("_href")
 
         super(MajesticSettings, self).__init__()
+
+    @property
+    def to_dict_mutable_fields(self):
+        return {x: getattr(self, x, None) for x in majestic_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        return {x: getattr(self, x, None) for x in majestic_immutable_fields}
