@@ -14,6 +14,7 @@ project_extra_fields = (
     "account_id",
     "project_settings",
     "majestic_settings",
+    "project_uploads",
     "crawls",
     "issues",
     "schedules",
@@ -47,6 +48,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         # relations
         self.id = project_data.get('id')
         self.account_id = account_id
+        self.project_uploads = []
         self.crawls = []
         self.issues = []
         self.schedules = []
@@ -113,6 +115,27 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         """
         return {x: getattr(self, x, None) for x in project_immutable_fields}
 
+    def load_project_uploads(self, connection=None, filters=None, **kwargs):
+        """Loads crawls into current instance
+
+        >>> self.load_project_uploads()
+        [[0 1] filename.csv, [0 1] filename2.csv]
+        >>> self.project_uploads
+        [[0 1] filename.csv, [0 1] filename2.csv]
+
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: list of project uploads
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        self.project_uploads = connection.get_project_uploads(self.account_id, self.id, filters=filters, **kwargs)
+        return self.project_uploads
+
     def load_crawls(self, connection=None, filters=None, **kwargs):
         """Loads crawls into current instance
 
@@ -253,6 +276,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         :type connection: deepcrawl.DeepCrawlConnection
         :return: HTTP 204 No Content
         """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         response = connection.delete_project(self.account_id, self.id)
         return response
 
@@ -295,6 +319,120 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         new_settings = {'custom_extractions': extractions_list}
         return connection.update_project_settings(self.account_id, self.id, new_settings)
 
+    """
+    PROJECT UPLOAD
+    """
+
+    def create_project_upload(self, upload_data: dict, files, connection=None):
+        """Create project upload
+
+        >>> self.create_project_upload(upload_data, files)
+        [0 1] filename.csv
+
+        :param upload_data: project upload configuration
+        :type upload_data: dict
+        :param files: project upload files
+        :type files: list
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: project upload instance
+        :rtype: DeepCrawlProjectUpload
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        project_upload = connection.create_project_upload(self.account_id, self.id, upload_data, files)
+        return project_upload
+
+    def get_project_upload(self, project_upload_id, connection=None):
+        """Get project upload
+
+        >>> self.get_project_upload(5)
+        [0 1] filename.csv
+
+        :param project_upload_id: issue id
+        :type project_upload_id: int
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: project upload instance
+        :rtype: DeepCrawlProjectUpload
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        project_upload = connection.get_project_upload(self.account_id, self.id, project_upload_id)
+        return project_upload
+
+    def enable_project_upload(self, project_upload_id, connection=None):
+        """Enable project upload
+
+        >>> self.enable_project_upload(5)
+        [0 1] filename.csv
+
+        :param project_upload_id: project upload id
+        :type project_upload_id: int
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: enable project upload instance
+        :rtype: DeepCrawlProjectUpload
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        project_upload = connection.enable_project_upload(self.account_id, self.id, project_upload_id)
+        return project_upload
+
+    def disable_project_upload(self, project_upload_id, connection=None):
+        """Disable project upload
+
+        >>> self.disable_project_upload(5)
+        [0 1] filename.csv
+
+        :param project_upload_id: project upload id
+        :type project_upload_id: int
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: disabled project upload instance
+        :rtype: DeepCrawlProjectUpload
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        project_upload = connection.disable_project_upload(self.account_id, self.id, project_upload_id)
+        return project_upload
+
+    def delete_project_upload(self, project_upload_id, connection=None):
+        """Delete current issue instance
+
+        >>> response = self.delete_project_upload(5)
+        >>> response.status_code
+        204
+
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: HTTP 204 No Content
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        response = connection.delete_project_upload(self.account_id, self.id, project_upload_id)
+        return response
+
+    def get_project_uploads(self, use_cache=True, connection=None, filters=None, **kwargs):
+        """Get project uploads for current instance
+
+        * use_cache=True > get_project_uploads will return cached project uploads or will do a call to DeepCrawl if project_uploads attribute is empty.
+        * use_cache=False > get_project_uploads will call DeepCrawl api and will override project_uploads attribute.
+
+        >>> self.get_project_uploads()
+        [[0 1] filename.csv, [0 1] filename2.csv]
+
+        :param use_cache:
+        :type use_cache: bool
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :return: list of project uploads
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        if use_cache and self.project_uploads:
+            return self.project_uploads
+        return self.load_project_uploads(connection=connection, filters=filters, **kwargs)
+
     """
     MAJESTIC
     """
