@@ -6,12 +6,15 @@ Report
 import deepcrawl
 from deepcrawl.utils import ImmutableAttributesMixin
 
-report_mutable_fields = (
+report_extra_fields = (
     'id',
     'account_id',
     'project_id',
     'crawl_id',
     'report_rows',
+)
+
+report_mutable_fields = report_extra_fields + (
     'report_type',
     'report_template',
     'total_rows',
@@ -105,6 +108,22 @@ class DeepCrawlReport(ImmutableAttributesMixin):
     def __str__(self):
         return f"[{self.account_id} {self.project_id} {self.crawl_id}] {self.id}"
 
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in report_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in report_immutable_fields}
+
     def load_report_rows(self, connection=None, filters=None, **kwargs):
         """Loads reports rows into current instance
 
